// wir kapseln unseren code um uns und den browser vor gegenseitiger Beeinflussung zu schützen
(function() {

	// hilfs-Funktion um über Listen zu iterieren
	// da wir auch mit "NodeList" arbeiten macht das Sinn, denn diese haben keine ".forEach()" Methode wie Arrays)
	function forEach(items, callback) {
		if (items && Array.isArray(items)) {
			items.forEach(callback);
		} else if ('length' in items) {
			for (var i = 0; i < items.length; ++i) {
				callback(items[i], i, items);
			}
		}
	}

	var LightManager = (function () {

		var lightIndex = 0;
		var differentLightCount = 3;
		var lightRotationMillis = 300;

		var rotationInterval;

		function startLightRotation() {
			if (!rotationInterval) {
				rotationInterval = window.setInterval(rotateLight, lightRotationMillis);
			}
		}

		function rotateLight() {
			var lights = document.querySelectorAll('.door .light');

			forEach(lights, function (light) {
				light.classList.remove('light_rotation_' + lightIndex % 3);
			});

			lightIndex++;

			forEach(lights, function (light) {
				light.classList.add('light_rotation_' + lightIndex % 3);
			});

		}

		function stopLightRotation(element) {
			window.clearInterval(rotationInterval);
			rotationInterval = null;

			var lights = element.querySelectorAll('.light');

			forEach(lights, function (light) {
				light.classList.add('light_selected');
			});
		}

		// dieser Rückgabewert wird der Variable "LightManager" zugewiesen
		// daher definieren wir hier welche öffentlichen Methoden es auf dem Objekt geben soll (alles andere bleibt privat)
		return {
			startLightRotation: startLightRotation,
			stopLightRotation: stopLightRotation
		}

	})();

	// wir initialisieren und starten alles wenn die App (Webseite) fertig geladen hat
	window.addEventListener('load', function() {
		LightManager.startLightRotation();

		var doors = document.querySelectorAll('.door');

		forEach(doors, function (door) {
			door.addEventListener('click', function(event) {

				LightManager.stopLightRotation(door);

				Client.sendEvent('selectedEntry', door.getAttribute('id'));
			});
		});
	});

	// Hier kommt das "openDoor" Event vom AppServer an.
	Client.addEventListener('openDoor', function(event){
		var data = event.data;
		var winningDoor = data['winningDoor'];
		var door = data['door'];
		var playText = data['text'];

		LightManager.startLightRotation();

		var resultElement = document.querySelector('#result' + winningDoor);
		var curtainElement = document.querySelector('#door' + door + ' .curtain');
		var playtextElement = document.getElementById('playtext');

		resultElement.setAttribute('src', 'i/result_knuddels.gif');
		curtainElement.classList.add('openCurtain'); // das bewegt ihn animiert nach oben (siehe CSS)
		playtextElement.innerHTML = playText;
	});

})();

